import logging

log = logging.getLogger(__name__)


class Access:
    """
    Access Object

    """

    def __init__(self, id, access_type, level, expires_at, web_url):
        """
        Initializes the access object

        :param id: Access Object ID, could be Gitlab Project ID or Group ID
        :param access_type: Defines a Gitlab "project" or "group"
        :param level: Access level of the user in group or project
        :param expires_at: Expire Date of the access level
        :param web_url: The weburl of the group or project
        """
        log.debug("__init__: starting ...")
        self.id = int(id)
        if access_type == "group" or access_type == "project":
            self.access_type = access_type
        else:
            raise ValueError(
                f"__init__: Unsupported access_type: {access_type} for web_url {web_url}")
        if level == 10 or level == 20 or level == 30 or level == 40 or level == 50:
            self.level = level
        else:
            raise ValueError(
                f"__init__: Unsupported level: {level} for web_url {web_url}")
        self.expires_at = expires_at
        if web_url.endswith("/"):
            web_url = web_url[:-1]
        self.web_url = web_url
        log.debug("__init__: finished.")

    def __getitem__(self, access):
        return access
