"""Console script for gitlab_usermgmt."""
import argparse
import sys
import gitlab_usermgmt.io
import gitlab_usermgmt.validator
import logging
from gitlab_usermgmt import __version__
from gitlab_usermgmt.usermgmt import Usermgmt


def main():
    """Console script for gitlab_usermgmt."""
    parser = argparse.ArgumentParser(
        description='The tool that helps you manage users in big GitLab groups and projects.',
        epilog='For more information go to: https://gitlab.com/ayeks/gitlab_usermgmt ' + __version__
    )

    parser.add_argument('-c', '--config',
                        help='your config json file',
                        dest='config',
                        required=False,
                        default="config.json",
                        type=str)
    parser.add_argument('--dry_run',
                        help='Do not apply anything to GitLab. Only read access to the API.',
                        dest='dry_run',
                        required=False,
                        action="store_true")
    parser.add_argument('-v', '--verbose',
                        help='Print debug log info',
                        action="store_true")
    args = parser.parse_args()

    log_format = '%(asctime)s - %(levelname)s - %(name)s - %(message)s'
    if args.verbose:
        logging.basicConfig(format=log_format, level=logging.DEBUG)
    else:
        logging.basicConfig(format=log_format, level=logging.INFO)

    for arg, value in sorted(vars(args).items()):
        logging.debug("Argument %s: %r", arg, value)

    config_dict = gitlab_usermgmt.io.read_json_to_dict(args.config)
    usermgmt = Usermgmt(config_dict, args.dry_run)
    usermgmt.auth()
    usermgmt.run()

    return 0


if __name__ == "__main__":
    sys.exit(main())  # pragma: no cover
